'use strict';
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, privateMap, value) {
    if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to set private field on non-instance");
    }
    privateMap.set(receiver, value);
    return value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, privateMap) {
    if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to get private field on non-instance");
    }
    return privateMap.get(receiver);
};
var _eventPromise;
Object.defineProperty(exports, "__esModule", { value: true });
exports.LifecycleEvent = void 0;
const CompletionTrigger_1 = require("./CompletionTrigger");
/**
 * Waits for a Chrome page lifecycle event.
 * Some examples include:
 *  - init
 *  - DOMContentLoaded
 *  - load
 *  - firstPaint
 *  - firstContentfulPaint
 *  - firstMeaningfulPaintCandidate
 *  - networkAlmostIdle
 *  - firstMeaningfulPaint
 *  - networkIdle
 *
 * @export
 * @class LifecycleEvent
 * @extends {CompletionTrigger}
 */
class LifecycleEvent extends CompletionTrigger_1.CompletionTrigger {
    /**
     * Creates an instance of the LifecycleEvent CompletionTrigger.
     * @param {string} [eventName] the name of the event to listen for.
     *  Defaults to `firstMeaningfulPaint`.
     * @param {number} [timeout] ms to wait until timing out.
     * @memberof LifecycleEvent
     */
    constructor(eventName, timeout) {
        super(timeout);
        this.eventName = eventName;
        _eventPromise.set(this, void 0);
    }
    async init(client) {
        const eName = this.eventName || 'firstMeaningfulPaint';
        const { Page } = client;
        await Page.setLifecycleEventsEnabled({ enabled: true });
        __classPrivateFieldSet(this, _eventPromise, new Promise((resolve) => {
            Page.lifecycleEvent((args) => {
                if (args.name === eName) {
                    resolve();
                }
            });
        }));
    }
    async wait(_client) {
        return Promise.race([
            __classPrivateFieldGet(this, _eventPromise),
            new Promise((_, reject) => setTimeout(() => reject(new Error(this.timeoutMessage)), this.timeout)),
        ]);
    }
}
exports.LifecycleEvent = LifecycleEvent;
_eventPromise = new WeakMap();
//# sourceMappingURL=LifecycleEvent.js.map